@@ -40,7 +40,16 @@ from datto.CleanDataframe import CleanDataframe
 
 class ModelResults:
     def most_similar_texts(
-        self, X, num_examples, text_column_name, num_topics=None, chosen_stopwords=set()
+        self,
+        X,
+        num_examples,
+        text_column_name,
+        num_topics=None,
+        chosen_stopwords=set(),
+        min_df=3,
+        max_df=0.1,
+        min_ngrams=1,
+        max_ngrams=3,
     ):
         """
         Uses NMF clustering to create n topics based on adjusted word frequencies
@@ -52,14 +61,22 @@ class ModelResults:
         text_column_name: str
         num_topics: int
             Optional - if none algorithm will determine best number
+        min_df: float
+            Minimum number/proportion of docs that need to have the words
+        max_df: float
+            Maximum number/proportion of docs that can have the words
+        min_ngrams: int
+            Minimum number of words needed in phrases found
+        max_ngrams: int
+            Maximum number of words in phrases found
 
         Returns
         --------
-        topic_words_df: DataFrame
-            Top 15 words/phrases per topic
-        combined_df: DataFrame
+        concated_topics: DataFrame
+            Top n words/phrases per topic
+        original_with_keywords: DataFrame
             Original text with topic number assigned to each
-
+        model: NMF model
         """
         X = X[~X[text_column_name].isna()]
         X = X[X[text_column_name] != ""]
@@ -80,10 +97,10 @@ class ModelResults:
         ct = CleanDataframe()
         vectorizer = TfidfVectorizer(
             tokenizer=ct.lematize,
-            ngram_range=(1, 3),
+            ngram_range=(min_ngrams, max_ngrams),
             stop_words=all_stop_words,
-            min_df=5,
-            max_df=0.4,
+            min_df=min_df,
+            max_df=max_df,
         )
         vectors = vectorizer.fit_transform(X[text_column_name]).todense()
 
@@ -200,7 +217,8 @@ class ModelResults:
         topic_words_df["sample_texts"] = sample_texts_lst
 
         topic_words_explode = pd.DataFrame(
-            topic_words_df["sample_texts"].tolist(), index=topic_words_df.index,
+            topic_words_df["sample_texts"].tolist(),
+            index=topic_words_df.index,
         )
 
         topic_words_explode.columns = [
@@ -281,7 +299,13 @@ class ModelResults:
         return shap_values
 
     def most_common_words_by_group(
-        self, X, text_col_name, group_col_name, num_examples, num_times_min, min_ngram,
+        self,
+        X,
+        text_col_name,
+        group_col_name,
+        num_examples,
+        num_times_min,
+        min_ngram,
     ):
         """
         Get the most commons phrases for defined groups.
@@ -344,7 +368,12 @@ class ModelResults:
         sums_by_col = (
             group_plus_vectors[
                 group_plus_vectors.columns[
-                    ~group_plus_vectors.columns.isin([text_col_name, "index",])
+                    ~group_plus_vectors.columns.isin(
+                        [
+                            text_col_name,
+                            "index",
+                        ]
+                    )
                 ]
             ]
             .groupby("group_column")
@@ -429,13 +458,19 @@ class ModelResults:
             print(f"Final Model ROC AUC: {roc_auc}")
 
             crosstab = pd.crosstab(
-                y_test, y_predicted, rownames=["Actual"], colnames=["Predicted"],
+                y_test,
+                y_predicted,
+                rownames=["Actual"],
+                colnames=["Predicted"],
             )
             print(crosstab)
             sum_crosstab = crosstab.to_numpy().sum()
             print(
                 pd.crosstab(
-                    y_test, y_predicted, rownames=["Actual"], colnames=["Predicted"],
+                    y_test,
+                    y_predicted,
+                    rownames=["Actual"],
+                    colnames=["Predicted"],
                 ).apply(lambda r: round(r / sum_crosstab, 3))
             )
         else:
@@ -452,7 +487,13 @@ class ModelResults:
         return trained_model, y_predicted
 
     def coefficients_summary(
-        self, X, y, num_repetitions, num_coefficients, model_type, multiclass=False,
+        self,
+        X,
+        y,
+        num_repetitions,
+        num_coefficients,
+        model_type,
+        multiclass=False,
     ):
         """
         Prints average coefficient values using a regression model.
@@ -529,7 +570,12 @@ class ModelResults:
             coefficients_df = coefficients_df.append(temp_df)
 
         summary_coefficients_df = pd.DataFrame(
-            coefficients_df.groupby("features").agg(["mean", "median",])
+            coefficients_df.groupby("features").agg(
+                [
+                    "mean",
+                    "median",
+                ]
+            )
         ).reset_index(drop=False)
 
         summary_coefficients_df.columns = [
